class V1::LanguagesController < ApplicationController
  include ::Paginator

  before_action :authenticate_user!, except: [:index, :show]
  before_action :set_language, only: [:show, :update, :destroy]

  # GET /languages
  # GET /languages.json
  def index
    languages = paginate Language
    render json: languages
  end

  # GET /learning_objects/1
  # GET /learning_objects/1.json
  def show
    render json: @language
  end

  # POST /languages
  # POST /languages.json
  def create
    @language = Language.new(language_params)

    if @language.save
      render json: @language, status: :created
    else
      render json: @language.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT /languages/1
  # PATCH/PUT /languages/1.json
  def update
    if @language.update(language_params)
      render json: @language, status: :ok
    else
      render json: @language.errors, status: :unprocessable_entity
    end
  end

  # DELETE /languages/1
  # DELETE /languages/1.json
  def destroy
    @language.destroy
    render status: :ok
  end

  private

  # Use callbacks to share common setup or constraints between actions.
  def set_language
    @language = Language.find(params[:id])
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def language_params
    params.require(:language).permit(:name, :code)
  end
end
